/* Blake, Nosko, Tadelis: Consumer Heterogeneity and Paid Search
brand experiments:
	plots
	computation of substitution from paid search to natural search
*/


// load and setup
use binghoo2, clear // binghoo_mediaplex.sql and binghoo_nebula.sql
gen treat=inlist(search_engine,"Bing","Yahoo","MSN") 

gen treatper=cal_dt>=td(5mar2012)
gen g_treatper=cal_dt>=td(1jul2012) & cal_dt<=td(31jul2012)
gen google=search_engine=="Google"
gen g_treated=g_treatper*google
drop if search_engine=="other"
gen treated=treat*treatper 
gen tot_clicks=ln(ps_clicks+ns_clicks)
label variable tot_clicks "Log Clicks"
label variable ps_clicks "Paid Clicks"
label variable ns_clicks "Natural Clicks"
capture encode search_engine, gen(se)
xtset se cal_dt


// plot - compress bing and yahoo to one
preserve
replace search_engine="MSN" if inlist(search_engine,"Bing","Yahoo")
collapse (sum) ps* ns* , by(cal_dt *treat* search_engine)
gen tot_clicks=(ps_clicks+ns_clicks)
gen lntot_clicks=ln(tot_clicks)
capture encode search_engine, gen(se)
gen google=search_engine=="Google"
label variable ps_clicks "Paid Clicks"
label variable ns_clicks "Natural Clicks"
bysort cal_dt: egen tottot_clicks=total(tot_clicks)

// MARCH
twoway (line ps_clicks cal_dt if search_engine=="MSN", lwidth(thick)) ///
	(line ns_clicks cal_dt if search_engine=="MSN", /* lcolor(dkgreen) */ lwidth(thick) lpattern(shortdash)) ///
	(line ns_clicks cal_dt if search_engine=="Google", lpattern(dash_dot) lwidth(thick)) ///
	if cal_dt<=td(25jun2012) , ///
	tlabel(1jan2012(7)25jun2012,angle(90) labsize(med)) ///
	name(march, replace) graphregion(color(white)) ylabel(,nogrid) ///
	ylabel(none) xtitle("") text("") caption("") ytitle("Count of Clicks") ///
	legend(label(1 "MSN Paid") label(2 "MSN Natural") label(3 "Goog Natural") rows(1) size(large))
graphexportpdf kwe1, dropeps
capture window manage close graph
// JULY
twoway (line ps_clicks cal_dt if search_engine=="Google", lwidth(thick)) ///
	(line ns_clicks cal_dt if search_engine=="Google", /* lcolor(dkgreen) */ lwidth(thick) lpattern(shortdash)) ///
	/* (line ns_clicks cal_dt if search_engine=="MSN", lpattern(dash_dot) lwidth(thick)) */ ///
	if cal_dt>td(1jun2012) & cal_dt<td(15sep2012), ///
	tlabel(1jun2012(7)15sep2012,angle(90) labsize(med)) ///
	name(july, replace) graphregion(color(white)) ylabel(,nogrid) ///
	ylabel(none) xtitle("") text("") caption("") ytitle("Count of Clicks") ///
	legend(label(1 "Goog Paid") label(2 "Goog Natural") /* label(3 "MSN Natural") */ rows(1) size(large))
graphexportpdf kwe2, dropeps
capture window manage close graph	
graph combine march july, rows(1) ysize(3) xsize(8) graphregion(color(white))
graphexportpdf kwe, dropeps
capture window manage close graph
restore


// quantifying substitution using pre-post and diff-in-diff regressions
foreach v in clicks {
	qui summ ps_`v' if cal_dt<td(15feb2012) & treat==1 & treatper==0
	local baseline=r(mean)

	// MSN - total (pre-post)
	qui eststo `v'0: reg tot_`v' treatper if cal_dt<=td(31mar2012) & cal_dt>td(1feb2012) & treat==1
	qui lincom 1+treatper
	dis "Tot Simple: " string(`r(estimate)'*100,"%9.2f") + "% (" + string(`r(se)'*100,"%9.2f")  ") of Total `v' retained"
	
	// MSN - total (dnd)
	qui eststo `v'1: reg tot_`v' treated treatper treat if cal_dt<=td(31mar2012) & cal_dt>=td(1feb2012) 
	qui reg tot_`v' treated ib1.se ibn.cal_dt i.se#c.cal_dt  if cal_dt<=td(31mar2012) & cal_dt>=td(1feb2012) 
		estadd local datefe = "Yes"
		estadd local sefe = "Yes"
		estadd local setrends = "Yes"
		estimates store `v'4
	qui lincom 1+treated
	dis "Tot DND: " string(`r(estimate)'*100,"%9.2f") + "% (" + string(`r(se)'*100,"%9.2f")  ") of Total `v' retained"
	
	// Goog - total dnd
	qui reg tot_`v' g_treatper if cal_dt>td(1jun2012) & cal_dt<td(30sep2012) & google==1
		estimates store g`v'1
}


// create table
label var treated Interaction
label var treatper "Test Period"
label var g_treated Interaction
label var g_treatper "Test Period"
esttab clicks0 clicks4 gclicks1 using kwe_clicks_only.tex, se stats(datefe setrends N, label("Date FE" "Platform Trends")) drop(*.cal_dt *b.*) varwidth(30) label ///
	rename(2.se "Google" 3.se "Yahoo" treated "Interaction" g_treated "Interaction" treatper "Period" g_treatper "Period") modelwidth(10) ///
	replace mgroup("MSN" "Google", pattern(1 0 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 

	