/* Blake, Nosko, Tadelis: Consumer Heterogeneity and Paid Search
estimate and plot frequency dnd interaction
*/

set more off
set matsize 11000
capture set maxvar 32000

 // define program for plotting
capture program drop plotestsc
program define plotestsc
	preserve
	clear
	estimates restore `1'
	parmest, norestore
	keep if strpos(parm, "`2'")>0
	gen buy_cnt=real(substr(parm,length("`2'")+2,strpos(parm, ".")))
	gen fit=$int1+buy_cnt*$slope1 if buy_cnt<=$inf
	replace fit=$int2+buy_cnt*$slope2 if buy_cnt>$inf
	outsheet using output/`1'_fixed.csv, comma replace
	twoway (rcap min95 max95 buy_cnt) (scatter estimate buy_cnt) (line fit buy_cnt, lpattern(dash) lwidth(medthick) lcolor(gray)), name(parm`1', replace) ///
		ytitle(% Change in Sales) ylabel(,format(%9.2f)) xtitle(User's Purchase Count for the 12 months ending $startdate) graphregion(color(white)) ///
		legend(order(2 1) label(1 "95% Conf Interval")) yline(0) xscale(range(-1(1)10)) 
	graphexportpdf output/`1'_fixed_spline.pdf, replace dropeps
end

// import data
use buycnt_apr_fixed, clear
gen search2=1
replace search2=0 if search==0 
	
// spline
global inf = 1
mkspline bc1 $inf bc2 = buy_cnt
eststo fitm: xtreg lngmb i.treatper##i.search2 1.treatper#1.search2#c.bc* ibn.buy_cnt i.date if buy_cnt<=10, cluster(dma) i(dma) fe
global slope1 = _b[1.search2#1.treatper#c.bc1]
global slope2 = _b[1.search2#1.treatper#c.bc2]
global int1 = _b[1.search2#1.treatper]
global int2 = $int1 - $inf*($slope2-$slope1)  // yup... good old point-slope stuff

// common slope (for footnote)
dis "post kink: slope = "  _b[1.search#1.treatper#c.bc2]  "; std err = "  _se[1.search#1.treatper#c.bc2]
	

// july experiment: regress and plot
keep if date>=td(1apr2012) & date<=td(22jul2012)

// interaction regression
qui eststo core5: xtreg lncore 1.search2#1.treatper#ibn.buy_cnt ibn.buy_cnt ibn.date if buy_cnt<=10, cluster(dma) fe i(dma)
estimates restore core5
	plotestsc core5 "1.search2#1.treatper" "Core GMB - Controlling for date & DMA fixed effects" 

	
	
	