/* Blake, Nosko, Tadelis: Consumer Heterogeneity and Paid Search
keyword ebay test in jan 2013 in germany (DE) for appendix*/
use de, clear

// code regions on/off
encode state, gen(st)
gen on=inlist(state,"DE-HB","DE-HE","DE-HH","DE-MV","DE-NI","DE-NW","DE-SN","DE-ST")
* PS_OFF = c("DE-BE","DE-BR","DE-BW","DE-BY","DE-RP","DE-SH","DE-SL","DE-TH")
gen period=0 if date>=td(1oct2012) & date<=td(31oct2012)
replace period=1 if date>=td(11jan2013) & date<=td(26jan2013)
gen period2=0 if date>=td(1dec2012) & date<=td(11jan2013)
replace period2=1 if date>=td(11jan2013) & date<=td(26jan2013)

// diff-in-diff regressions
gen lngmb=ln(gmb)
reg lngmb i.on##i.period
qui {
eststo reg1: xtreg lngmb i.on##i.period2 ib1.date , fe i(st) cluster(st)
eststo reg2: xtreg lngmb i.on##i.period2 ib1.date if date>=td(1jan2013), fe i(st) cluster(st)
	estadd local only2013 = "Yes"
eststo reg3: xtreg lngmb i.on##i.period2 i.st#c.date ib1.date if date>=td(1jan2013), fe i(st) cluster(st)
	estadd local statetrnd = "Yes"
	estadd local only2013 = "Yes"
}
estadd local datefe = "Yes", replace: reg*
estadd local dmafe = "Yes", replace: reg*
label var lngmb "Log Sales"
esttab reg* using kwe_de_jan13_tbl.tex, varwidth(20) keep(Interaction) rename(1.on#1.period2 "Interaction")  stats(dmafe datefe only2013 statetrnd  N, label("State Fixed Effects" "Date Fixed Effects" "Post Jan 1" "State Trends")) label se note(Standard errors, clustered on the state, in parentheses)


// plot diff-in-diff
preserve
collapse (mean) lngmb, by(date on period2)
* xtline lngmb if period2!=., i(on) t(date) overlay
reshape wide lngmb, i(date) j(on)
gen lndiff=lngmb1-lngmb0
label variable lndiff "Log On - Log Off"
label variable period2 "Test"
twoway (area period2 date if period2!=., yaxis(2 2) color(dknavy) fintensity(inten20) lwidth(none)) (line lndiff date if period2!=., yaxis(1)) , ytitle("", axis(2)) yscale(off range(.5 1) axis(2)) tlabel(1dec2012(2)26jan2013,angle(90) labsize(med)) legend(rows(1) size(large) order(2 3 4 1)) xtitle("") graphregion(color(white)) xtitle("") text("") caption("")
graphexportpdf kwe_de_jan13_plot, dropeps
restore


