/* Blake, Nosko, Tadelis: Consumer Heterogeneity and Paid Search
non-brand diff-n-diff plots, regs, and robustness
this version uses only fixed price sales (no auctions)
 */

set more off
clear all
set maxvar 11000
set matsize 11000

global sdate=td(1apr2012)

// load data
use ../dma/venkat_fixed
rename gmb_usd gmb
drop if dma==.
keep date dma gmb gmb_core items
gen search=0 if inlist(dma,500,505,511,513,517,521,525,528,534,536,542,544,545,546,547,548,550,556,557,561,563,565,566,576,577,581,596,606,609,611,613,617,622,624,627,635,644,656,671,673,676,678,679,686,687,691,692,693,705,710,711,734,737,743,744,745,747,749,751,755,757,758,759,801,802,811,813,866)
replace search=1 if inlist(dma,501,503,507,510,516,518,519,522,523,524,529,532,537,538,549,551,552,555,558,559,564,567,571,574,575,582,584,592,597,600,602,605,618,623,631,632,634,637,638,639,640,642,647,650,657,659,669,670,698,702,717,722,746,754,760,764,765,767,773,790,800,804,819,839,862)
gen subgroup2=inlist(dma,501,510,839,790,518,640,532,637,523,575,574,670,519,551,634,642,605,503,698,516,600,592,559,717,746,764,657,549,773,582,584,638,558,552,528,613,609,548,566,635,577,563,622,693,744,556,686,671,542,547,679,513,500,811,801,576,687,581,705,624,758,673,611,749,692,565,755,737,745,747,596)
gen treatper=date>=td(22may2012) & date<=td(22jul2012)
keep if date<=td(22jul2012)
keep if date>=$sdate
gen treated=treatper*search
gen lncore=ln(gmb_core)
label variable lncore "Log Sales"
tempfile dmagmb
save `dmagmb', replace

// join in paid search attributed sales (only for plot showing drop in attribution)
use ../dma/pse_dma, clear
keep date dma gmbPAID_SEARCH_NON_BRAND gmbPAID_SEARCH_BRAND gmbSITE_SEO_HP gmbSITE_SEO_NON_HP lngmbPAID_SEARCH_BRAND lngmbPAID_SEARCH_NON_BRAND lngmbSITE_SEO_HP lngmbSITE_SEO_NON_HP
keep if date>=$sdate
joinby date dma using `dmagmb', unmatched(both)

// drop in attribution for note
tab search treatper, summarize(gmbPAID_SEARCH_NON_BRAND)
tab search treatper, summarize(lngmbPAID_SEARCH_NON_BRAND)

// collapse to daily level for plots
preserve
collapse (sum) gmbPAID* gmbSITE_* gmb (mean) avggmb=gmb, by(date search) 
keep if date>=td(1apr2012)
replace search=2 if search==.
label define region 0 "Test" 1 "Control" 2 "Rest of U.S."
label values search region
xtset search date

// plot attributed shutoff
xtline gmbPAID_SEARCH_NON_BRAND if date<td(21july2012), overlay tlabel(1apr2012(7)22jul2012,angle(90) labsize(med)) ///
	name(test, replace) graphregion(color(white)) ylabel(,nogrid) ///
	ylabel(none) xtitle("") text("") caption("") ytitle("") ///
	legend(rows(1) size(large)) ytitle(Sales) ///
	plot2opts(lpattern(shortdash)) plot3opts(lpattern(dash_dot))
graphexportpdf current/tracked_region, dropeps

// plot total outcome
keep date search avggmb
reshape wide avggmb, i(date) j(search)
gen ratio=avggmb1/avggmb0
gen diff=(avggmb1-avggmb0)/1000
gen lndiff=ln(avggmb1)-ln(avggmb0)
gen post=date>td(22may2012)
label var ratio "On/Off"
label var diff "(On-Off)"
label var lndiff "Log(On)-Log(Off)"
label var post "Test"
twoway (area post date, color(dknavy) fintensity(inten20) lwidth(none)) (line ratio date, yaxis(4)) (line diff date, yaxis(2) lpattern(shortdash)) (line lndiff date, yaxis(3) lpattern(dash_dot)) , ///
	name(diffratio, replace) graphregion(color(white)) xtitle("") text("") caption("") ///
	yscale(off range(.5 1)) yscale(axis(2) range(0 10 100)) yscale( axis(3) range(.3 .9)) yscale( axis(4) range(0 1))  /* ytitle("On-Off (Thsnd $)" " ", axis(2)) */ ///
	ylabel(1.2(.2)1.5, axis(4)) ylabel(.2(.1).4, axis(3)) ylabel(20(20)60, axis(2)) ///
	ytitle("", axis(2)) ytitle("", axis(3)) ytitle("", axis(4)) ///
	tlabel(1apr2012(7)22jul2012,angle(90) labsize(med)) ///
	legend(rows(2) size(large) order(2 3 4 1))
graphexportpdf current/before_after, dropeps
graph drop _all
restore


// DIFF IN DIFF REGRESSIONS USING WHOLE COUNTRY
gen search2=search
replace search2=1 if search2==.
gen treated2=treatper*search2
label variable search2 "Search Group"
label variable treated2 "Interaction"
label variable treatper "Experiment Period"
foreach v of varlist lncore {
	qui {
		eststo `v'1: reg `v' treated2 treatper search2, cluster(dma)
		xtreg `v' treated2 ibn.date, fe i(dma) cluster(dma)
			estadd local datefe = "Yes"
			estadd local dmafe = "Yes"
			eststo `v'2
	}
}

// DMA LEVEL REGRESSIONS
preserve
collapse (sum) gmb_core, by(dma treatper search2 treated2)
gen lncore=ln(gmb_core)
label variable lncore "Log Sales"
qui eststo dl: reg lncore treated2 treatper search2, cluster(dma)
qui eststo dlfe: xtreg lncore treated2 treatper, fe i(dma) cluster(dma)
	estadd local dmafe = "Yes"
restore

// create table
esttab lncore* dl dlfe using current/dma_level_fs.tex, se label drop(*.date _cons) stats(dmafe N, label("DMA Fixed Effects")) note(Standard errors, clustered on the DMA, in parentheses) star(* .1 ** .05 *** .01) mgroup(Daily Totaled, pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  replace


// Candidacy IV section of appendix (Randall Lewis 'LATE' approach)
preserve
joinby date dma using ../roi/spend_all
gen candidate = search!=.
collapse (sum) gmb_core cost, by(dma treatper search2 candidate)
gen lncore=ln(gmb_core)
gen rev=gmb_core*.095
gen lnrev=ln(rev)
gen lncost=ln(cost)
reshape wide *core *cost *rev, j(treatper) i(dma search2 candidate)

label variable lncore1 "ln(Test Period Sales)"
label variable lncore0 "ln(Pre Period Sales)"
label var rev1 "Test Period Revenue"
label var rev0 "Pre Period Revenue"
label var cost1 "Test Period Cost"
label var cost0 "Pre Period Cost"
label var lnrev1 "ln(Test Period Revenue)"
label var lnrev0 "ln(Pre Period Revenue)"
label var lncost1 "ln(Test Period Cost)"
label var lncost0 "ln(Pre Period Cost)"
label var candidate "Candidate for Off DMA"
label var search2 "Ads On"
qui eststo civ_dir: ivreg2 lncore1 (search2 = candidate) lncore0 
qui eststo civ_roi: ivreg2 lnrev1 (lncost1 = candidate) lnrev0 lncost0
qui eststo lev_civ_roi: ivreg2 rev1 (cost1 = candidate) rev0 cost0
esttab civ* using current/cand_iv.tex, se star(* .1 ** .05 *** .01) label replace order(search2 lncost1) drop(_cons*)
restore


// Candidacy IV section of appendix - for robustness of randomization
gen candidate = search!=.
label var candidate "Candidate for Off DMA"
qui eststo candon: reg lncore 1.candidate#1.treatper candidate treatper ib2.date ib2.dma, cluster(dma)
	estadd local datefe = "Yes"
	estadd local dmafe = "Yes"
qui eststo onon: reg lncore 1.candidate#1.treatper candidate treatper ib2.date ib2.dma if search2==1 , cluster(dma)
	estadd local datefe = "Yes"
	estadd local dmafe = "Yes"
	estadd local ononly = "Yes"
esttab candon onon using current/cand_dnd.tex, se label order(Interaction) note(Standard errors, clustered on the DMA, in parentheses) star(* .1 ** .05 *** .01) rename(1.candidate#1.treatper "Interaction") stats(datefe dmafe ononly N, label("Date Fixed Effects" "DMA Fixed Effects" "Ads On Only DMAs")) drop(*.date *.dma)



