/* Blake, Nosko, Tadelis: Consumer Heterogeneity and Paid Search
Recency interaction estimates
*/

clear all
set more off
set matsize 11000
set maxvar 32000 

// prep data
capture use recency_30_fixed, clear
if _rc !=0 {
	clear
	loadsql using "dma_recency_30_fixed.sql", dsn("mozart") sql
	* loadsql using "dma_recency.sql", dsn("mozart") sql
	renvars, lower
	gen lngmb=ln(gmb) 
	rename dt date
	drop if dma==. 
	gen search=0 if inlist(dma,500,505,511,513,517,521,525,528,534,536,542,544,545,546,547,548,550,556,557,561,563,565,566,576,577,581,596,606,609,611,613,617,622,624,627,635,644,656,671,673,676,678,679,686,687,691,692,693,705,710,711,734,737,743,744,745,747,749,751,755,757,758,759,801,802,811,813,866)
	replace search=1 if inlist(dma,501,503,507,510,516,518,519,522,523,524,529,532,537,538,549,551,552,555,558,559,564,567,571,574,575,582,584,592,597,600,602,605,618,623,631,632,634,637,638,639,640,642,647,650,657,659,669,670,698,702,717,722,746,754,760,764,765,767,773,790,800,804,819,839,862)
	gen treatper=date>=td(23may2012) 
	save recency_30_fixed, replace
}

// plots for referee report response - show fig 3 by recent and non-recent users
preserve
gen recent=recency<=210
collapse (sum) gmb_core, by(date dma search recent) 
gen lngmb=ln(gmb_core)
collapse (mean) avggmb=gmb_core lngmb, by(date search recent) 

replace search=2 if search==.
label define region 0 "Test" 1 "Control" 2 "Rest of U.S."
label values search region

keep date recent search avggmb lngmb
reshape wide avggmb lngmb, i(date recent) j(search)
gen lndiff=lngmb1-lngmb0
gen post=date>td(22may2012)
label var lndiff "Log(On)-Log(Off)"
label var post "Test" 
bysort recent post: egen lnavg=mean(lndiff)
sort date post recent
twoway (area post date, color(dknavy) fintensity(inten20) lwidth(none) yaxis(2)) ///
	(line lndiff date if recent==0, yaxis(1) lpattern(dash_dot)) ///
	(line lnavg date if post==0 & recent==0, lcolor(dknavy)) (line lnavg date if post==1 & recent==0, lcolor(dknavy)) , ///
	name(diffratio00, replace) graphregion(color(white)) xtitle("") text("") caption("") ///
	yscale(off range(.5 1) axis(2)) ///
	ylabel(-.2(.05).1, axis(1)) ///
	ytitle("", axis(1)) ///
	tlabel(1apr2012(7)22jul2012,angle(90) labsize(med)) ///
	legend(rows(1) size(large) order(2 1)) 
graphexportpdf before_after_rec00, dropeps
twoway (area post date, color(dknavy) fintensity(inten20) lwidth(none) yaxis(2)) ///
	(line lndiff date if recent==1, yaxis(1) lpattern(dash_dot)) ///
	(line lnavg date if post==0 & recent==1, lcolor(dknavy)) (line lnavg date if post==1 & recent==1, lcolor(dknavy)) , ///
	name(diffratio01, replace) graphregion(color(white)) xtitle("") text("") caption("") ///
	yscale(off range(.5 1) axis(2)) ///
	ylabel(-.2(.05).1, axis(1)) ///
	ytitle("", axis(1)) ///
	tlabel(1apr2012(7)22jul2012,angle(90) labsize(med)) ///
	legend(rows(1) size(large) order(2 1)) 
graphexportpdf before_after_rec01, dropeps
restore

	
// spline
gen old=recency>60
xtreg lngmb i.search##i.treatper#i.old#c.recency i.recency, cluster(dma) i(dma) fe
global int = _b[1.search#1.old#c.recency]+_b[1.treatper#1.old#c.recency]
global slope1 = _b[1.search#1.treatper#0.old#c.recency]
global slope2 = _b[1.search#1.treatper#1.old#c.recency]
dis "post kink: slope = "  _b[1.search#1.treatper#1.old#c.recency]  "; std err = "  _se[1.search#1.treatper#1.old#c.recency]
test 1.search#1.treatper#1.old#c.recency=0
dis "post kink: slope = "  _b[1.search#1.treatper#1.old#c.recency]  "; std err = "  _se[1.search#1.treatper#1.old#c.recency] "; p-val = " r(p)
test 1.search#1.treatper#0.old#c.recency=1.search#1.treatper#1.old#c.recency
estadd scalar difftest=r(p)
esttab using spline_reg.tex, replace se varwidth(40) indicate( "Recency Bucket FE" = *0.recency) drop(*o.recency 0b.recency) label order(1.search#1.treatper#0b.old#c.recency 1.search#1.treatper#1.old#c.recency) varlabel( 1.search#1.treatper#1.old#c.recency "90+ Days Incrementality Slope"  1.search#1.treatper#0b.old#c.recency "0-90 Days Incrementality Slope" 0b.search#0b.old#c.recency "(Search = 0) x (0-90 Days Recency) x Recency" 0b.search#1.old#c.recency "(Search = 0) x (90+ Days Recency) x Recency" 0b.treatper#1.old#c.recency "(Post = 0) x (90+ Days Recency) x Recency" 0b.treatper#0b.old#c.recency "(Post = 0) x (0-90 Days Recency) x Recency" 1.treatper#0b.old#c.recency "(Post = 1) x (90+ Days Recency) x Recency"  1.treatper#1.old#c.recency "(Post = 1) x (90+ Days Recency) x Recency" _cons "Constant") stats(difftest, label("90 day break p-value")) nodepvar nonum nomtitle



// program for plotting estimates
capture prog drop plotestsc
program define plotestsc
	preserve
	clear
	parmest, norestore
	keep if strpos(parm, "1.search#1.treatper")>0
	gen x=real(substr(parm,21,strpos(substr(parm,21,.), ".")))
	gen fit=x*$slope1 if x<=90
	replace fit=$int+x*$slope2 if x>90
	twoway (rcap min95 max95 x) (scatter estimate x) , name(parm`1', replace) ///
		ytitle(% Change in Sales) ylabel(,format(%9.2f)) xtitle(Days since User's Last Purchase) graphregion(color(white)) ///
		/* title(Paid Search Sales Impact By Recency) subtitle("`2'", size(vsmall)) */ yline(0) ///
		legend(order(2 1 3) label(1 "95% Conf Interval") rows(1)) xlabel(0(30)360)
	graphexportpdf `1'.pdf, replace dropeps
	twoway (rcap min95 max95 x) (scatter estimate x) (line fit x, lpattern(dash) lwidth(medthick) lcolor(gray)), name(parm`1', replace) ///
		ytitle(% Change in Sales) ylabel(,format(%9.2f)) xtitle(Days since User's Last Purchase) graphregion(color(white)) ///
		/* title(Paid Search Sales Impact By Recency) subtitle("`2'", size(vsmall)) */ yline(0) ///
		legend(order(2 1 3) label(1 "95% Conf Interval") label(3 "Spline") rows(1)) xlabel(0(30)360)
	graphexportpdf `1'_wspline.pdf, replace dropeps
end


// interaction regressions
	eststo fe2: xtreg lngmb i.search##i.treatper#ibn.recency ibn.recency i.date, fe i(dma) cluster(dma)
		plotestsc fe2 "Date and DMA Fixed Effects" 
		
	
	
	
	
	
	
	