/* Blake, Nosko, Tadelis: Consumer Heterogeneity and Paid Search
OLS and IV estimation of ROI
*/

// load data
clear
set matsize 11000
use spend_all, clear
joinby dma date using ../dma/venkat_fixed
global sdate=td(1apr2012)
keep if date>=$sdate & date<=td(22jul2012)
gen rev=gmb_core*.095
gen lnrev=ln(rev)
gen lncost=ln(cost)
gen lncore=ln(gmb_core)

// ols
estimates drop _all
qui eststo rev_lnln_ols: reg lnrev lncost if date<=td(20may2012), cluster(dma) // using only pre-period ot avoid contamination
qui eststo rev_lnln_olsfe: xtreg lnrev lncost i.date i.dma#c.date if date<=td(20may2012), fe i(dma) cluster(dma)

// iv - using whole country
gen search2=1
replace search2=0 if inlist(dma,500,505,511,513,517,521,525,528,534,536,542,544,545,546,547,548,550,556,557,561,563,565,566,576,577,581,596,606,609,611,613,617,622,624,627,635,644,656,671,673,676,678,679,686,687,691,692,693,705,710,711,734,737,743,744,745,747,749,751,755,757,758,759,801,802,811,813,866)
gen treatper=date>=td(22may2012) & date<=td(22jul2012)
gen treated2=search2*treatper
label variable treated2 "Interaction Dummy"
qui eststo rev_lnln2: ivreg2 lnrev ( lncost = treated2 search2 treatper), cluster(dma)
qui eststo rev_lnln2xt: xi: xtivreg2 lnrev ( lncost = treated2 search2 treatper) i.date, fe i(dma) cluster(dma)

// report coefficients... fed to Table1.xlsx for translation to ROI
esttab rev_lnln_ols rev_lnln_olsfe rev_lnln2 rev_lnln2xt, se keep(*cost )  stats(dmafe datefe N, label("DMA Fixed Effects" "Date Fixed Effects")) mgroup("OLS" "IV" "DnD", pattern(1 0 1 0 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) label nomtitles replace star(* .1 ** .05 *** .01) tex substitute(\_ _)

// in levels (for appendix)
label var cost "Cost (\\$)"
label var rev "Revenue (\\$)"
qui eststo roi_lev: xi: xtivreg2 rev (cost=search2 treated2 treatper) i.date,fe i(dma) cluster(dma) 
	estadd local dmafe = "Yes"
	estadd local datefe = "Yes"
esttab roi_lev, drop(_I*) label star(* .1 ** .05 *** .01) se  stats(dmafe datefe N, label("DMA Fixed Effects" "Date Fixed Effects"))
esttab roi_lev using output_current/roi_lev.tex, drop(_I*) label star(* .1 ** .05 *** .01) se  stats(dmafe datefe N, label("DMA Fixed Effects" "Date Fixed Effects")) replace


